Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(700)

Unified Diff: sdk/lib/_internal/compiler/implementation/compile_time_constants.dart

Issue 11783009: Big merge from experimental to bleeding edge. (Closed) Base URL: https://dart.googlecode.com/svn/branches/bleeding_edge/dart
Patch Set: Created 7 years, 11 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: sdk/lib/_internal/compiler/implementation/compile_time_constants.dart
diff --git a/sdk/lib/_internal/compiler/implementation/compile_time_constants.dart b/sdk/lib/_internal/compiler/implementation/compile_time_constants.dart
index cb1439a52e185e4b6b1b9d43f80902f52e73b632..6dd7695e7a72c87b264e6682db2a90bfb3d64bf5 100644
--- a/sdk/lib/_internal/compiler/implementation/compile_time_constants.dart
+++ b/sdk/lib/_internal/compiler/implementation/compile_time_constants.dart
@@ -221,12 +221,12 @@ class ConstantHandler extends CompilerTask {
}
/**
* Returns a [List] of static non final fields that need to be initialized.
* The list must be evaluated in order since the fields might depend on each
* other.
*/
- List<VariableElement> getStaticNonFinalFieldsForEmission() {
- return initialVariableValues.keys.filter((element) {
+ Iterable<VariableElement> getStaticNonFinalFieldsForEmission() {
+ return initialVariableValues.keys.where((element) {
return element.kind == ElementKind.FIELD
&& !element.isInstanceMember()
&& !element.modifiers.isFinal();
@@ -234,12 +234,12 @@ class ConstantHandler extends CompilerTask {
}
/**
* Returns a [List] of static const fields that need to be initialized. The
* list must be evaluated in order since the fields might depend on each
* other.
*/
- List<VariableElement> getStaticFinalFieldsForEmission() {
- return initialVariableValues.keys.filter((element) {
+ Iterable<VariableElement> getStaticFinalFieldsForEmission() {
+ return initialVariableValues.keys.where((element) {
return element.kind == ElementKind.FIELD
&& !element.isInstanceMember()
&& element.modifiers.isFinal();
@@ -221,12 +221,12 @@ class ConstantHandler extends CompilerTask {
}
/**
- * Returns a [List] of static non final fields that need to be initialized.
- * The list must be evaluated in order since the fields might depend on each
- * other.
+ * Returns an [Iterable] of static non final fields that need to be
+ * initialized. The fields list must be evaluated in order since they might
+ * depend on each other.
*/
@@ -234,12 +234,12 @@ class ConstantHandler extends CompilerTask {
}
/**
- * Returns a [List] of static const fields that need to be initialized. The
- * list must be evaluated in order since the fields might depend on each
+ * Returns an [Iterable] of static const fields that need to be initialized.
+ * The fields must be evaluated in order since they might depend on each
* other.
*/
« no previous file with comments | « sdk/lib/_internal/compiler/implementation/code_buffer.dart ('k') | sdk/lib/_internal/compiler/implementation/compiler.dart » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698